==> jc-1.4.0.tar.gz: javax/swing/text/StyleContext__24SimpleFontSpec.h <==
// class javax.swing.text.StyleContext$SimpleFontSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 757926f6eb81193f javax_swing_text_StyleContext__24SimpleFontSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_
#define _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$object;

typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods;
typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable;
typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype;

// Constructors
extern void _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual methods
extern jboolean _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *);
};

// Vtable
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods	javax_swing_text_StyleContext__24SimpleFontSpec;
};

// Vtype
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs {
	struct _jc_java_lang_String$object	*family;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs {
    _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs	javax_swing_text_StyleContext__24SimpleFontSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs {
	jint	style;
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs	javax_swing_text_StyleContext__24SimpleFontSpec;
};

// Object instance structure
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object {
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype	*vtype;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype _jc_javax_swing_text_StyleContext__24SimpleFontSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleContext__24SimpleFontSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleContext__24SimpleFontSpec$class_object;

#endif	/* _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyleContext__24SimpleFontSpec.h <==
// class javax.swing.text.StyleContext$SimpleFontSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 60cd551e491c69cb javax_swing_text_StyleContext__24SimpleFontSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_
#define _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs;
typedef struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$object;

typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods;
typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable;
typedef const struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype;

// Constructors
extern void _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_swing_text_StyleContext__24SimpleFontSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vmethods	javax_swing_text_StyleContext__24SimpleFontSpec;
};

// Vtype
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs {
	struct _jc_java_lang_String$object	*family;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs {
    _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_refs	javax_swing_text_StyleContext__24SimpleFontSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs {
	jint	style;
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleContext__24SimpleFontSpec$sub_nonrefs	javax_swing_text_StyleContext__24SimpleFontSpec;
};

// Object instance structure
struct _jc_javax_swing_text_StyleContext__24SimpleFontSpec$object {
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype	*vtype;
	_jc_javax_swing_text_StyleContext__24SimpleFontSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleContext__24SimpleFontSpec$vtype _jc_javax_swing_text_StyleContext__24SimpleFontSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleContext__24SimpleFontSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleContext__24SimpleFontSpec$class_object;

#endif	/* _JC_javax_swing_text_StyleContext__24SimpleFontSpec_H_ */
